@@ -1,8 +1,7 @@
 package Sidef::Object::Lazy {
 
     use 5.014;
-
-    use overload q{""} => \&to_a;
+    ##use overload q{""} => \&to_a;
 
     sub new {
         my (undef, %opt) = @_;
@@ -96,6 +95,8 @@ package Sidef::Object::Lazy {
         $self;
     }
 
+    *select = \&grep;
+
     sub map {
         my ($self, $block) = @_;
         push @{$self->{calls}}, sub {
