@@ -46,7 +46,7 @@ package Sidef::Object::Object {
             }
         }
 
-        my $cmp = ((ref($obj1) ? Scalar::Util::refaddr($obj1) : ('-inf' + 0))
+        my $cmp = ((CORE::ref($obj1) ? Scalar::Util::refaddr($obj1) : ('-inf' + 0))
                    <=> (CORE::ref($obj2) ? Scalar::Util::refaddr($obj2) : ('-inf' + 0)));
 
             $cmp < 0 ? Sidef::Types::Number::Number::MONE
@@ -82,20 +82,20 @@ package Sidef::Object::Object {
 
     *println = \&say;
 
-    sub lazy {
-        my ($self) = @_;
-        Sidef::Object::Lazy->new(obj => $self);
-    }
-
     sub print {
         (CORE::print @_)
           ? (Sidef::Types::Bool::Bool::TRUE)
           : (Sidef::Types::Bool::Bool::FALSE);
     }
 
+    sub lazy {
+        my ($self) = @_;
+        Sidef::Object::Lazy->new(obj => $self);
+    }
+
     sub method {
         my ($self, $method, @args) = @_;
-        Sidef::Variable::LazyMethod->new(obj => $self, method => $method, args => \@args);
+        Sidef::Object::LazyMethod->new(obj => $self, method => $method, args => \@args);
     }
 
     sub object_id {
@@ -167,6 +167,23 @@ package Sidef::Object::Object {
         $_[0]->new(CORE::join('', @_[1 .. $#_]));
     }
 
+    sub dump {
+        my ($obj) = @_;
+        my $type = Sidef::normalize_type(CORE::ref($obj) ? CORE::ref($obj) : $obj);
+        Scalar::Util::reftype($obj) eq 'HASH' or return $type;
+        my @keys = CORE::sort CORE::keys(%{$obj});
+        Sidef::Types::String::String->new(
+            "$type(" . CORE::join(
+                ', ',
+                map {
+                    my $str = UNIVERSAL::can($obj->{$_}, 'dump') ? $obj->{$_}->dump : "$obj->{$_}";
+                    "$_: $str";
+                  } @keys
+              )
+              . ')'
+        );
+    }
+
     {
         no strict 'refs';
 
@@ -206,10 +223,10 @@ package Sidef::Object::Object {
             foreach my $method (grep { $_ !~ /^[(_]/ and defined(&{$ref . '::' . $_}) } keys %{$ref . '::'}) {
                 $methods{$method} = (
                                      $alias{\&{$ref . '::' . $method}} //=
-                                       Sidef::Variable::LazyMethod->new(
-                                                                        obj    => $self,
-                                                                        method => \&{$ref . '::' . $method}
-                                                                       )
+                                       Sidef::Object::LazyMethod->new(
+                                                                      obj    => $self,
+                                                                      method => \&{$ref . '::' . $method}
+                                                                     )
                                     );
             }
 
