@@ -52,7 +52,6 @@ package Sidef::Optimizer {
               Sidef::DataTypes::Glob::Pipe            Sidef::Types::Glob::Pipe
               Sidef::DataTypes::Glob::Dir             Sidef::Types::Glob::Dir
               Sidef::DataTypes::Glob::File            Sidef::Types::Glob::File
-              Sidef::DataTypes::Variable::LazyMethod  Sidef::Variable::LazyMethod
               )
         );
 
@@ -271,7 +270,7 @@ package Sidef::Optimizer {
 
             # Number.method(Number)
             (
-             map { [$_, [table(NUMBER)]] }
+             map { [$_, [table(NUMBER, COMPLEX)]] }
                methods(NUMBER, qw(
                    + - / * % %% **
 
@@ -312,9 +311,12 @@ package Sidef::Optimizer {
                    factorial
                    sqrt isqrt
                    next_pow2
-                   abs
+                   abs int
+
+                   exp
+                   exp2
+                   exp10
 
-                   exp int
                    cos sin
 
                    ln
@@ -536,7 +538,6 @@ package Sidef::Optimizer {
                    div
                    add
                    sub
-                   exp
                    log
                    pow
 
@@ -554,6 +555,10 @@ package Sidef::Optimizer {
                    dec
                    abs
 
+                   exp
+                   exp2
+                   exp10
+
                    log
                    log2
                    log10
@@ -944,7 +949,9 @@ package Sidef::Optimizer {
                     foreach my $j (0 .. $#{$call->{arg}}) {
                         my $arg = $call->{arg}[$j];
                         push @{$obj->{call}[$i]{arg}},
-                          ref($arg) eq 'HASH' ? do { my %arg = $self->optimize($arg); \%arg } : $arg;
+                            ref($arg) eq 'HASH' ? do { my %arg = $self->optimize($arg); \%arg }
+                          : ref($arg) ? $self->optimize_expr({self => $arg})
+                          :             $arg;
                     }
                 }
 
@@ -953,7 +960,9 @@ package Sidef::Optimizer {
                     foreach my $j (0 .. $#{$call->{block}}) {
                         my $arg = $call->{block}[$j];
                         push @{$obj->{call}[$i]{block}},
-                          ref $arg eq 'HASH' ? do { my %arg = $self->optimize($arg); \%arg } : $arg;
+                            ref $arg eq 'HASH' ? do { my %arg = $self->optimize($arg); \%arg }
+                          : ref($arg) ? $self->optimize_expr({self => $arg})
+                          :             $arg;
                     }
                 }
 
