@@ -186,7 +186,7 @@ package Sidef::Types::Array::Array {
     sub or {
         my ($self, $array) = @_;
 
-        #$self->xor($array)->concat($self->and($array));
+        #$self->and($array)->concat($self->xor($array));
         $self->concat($array)->uniq;
     }
 
@@ -294,7 +294,7 @@ package Sidef::Types::Array::Array {
                 push @new, $x[$i];
                 ++$i;
             }
-            elsif (ref($cmp) ? $cmp->is_one : ($cmp == -1)) {
+            elsif (ref($cmp) ? $cmp->is_one : ($cmp == 1)) {
                 ++$j;
             }
             else {
@@ -312,7 +312,7 @@ package Sidef::Types::Array::Array {
     sub concat {
         my ($self, $arg) = @_;
 
-        eval { $arg->isa('ARRAY') }
+        UNIVERSAL::isa($arg, 'ARRAY')
           ? $self->new(@{$self}, @{$arg})
           : $self->new(@{$self}, $arg);
     }
@@ -834,6 +834,36 @@ package Sidef::Types::Array::Array {
         $self;
     }
 
+    sub slice_before {
+        my ($self, $block) = @_;
+
+        my @new;
+        my $i = 0;
+        foreach my $item (@{$self}) {
+            if ($block->run($item)) {
+                ++$i if @new;
+            }
+            push @{$new[$i]}, $item;
+        }
+
+        $self->new([map { $self->new($_) } @new]);
+    }
+
+    sub slice_after {
+        my ($self, $block) = @_;
+
+        my @new;
+        my $i = 0;
+        foreach my $item (@{$self}) {
+            push @{$new[$i]}, $item;
+            if ($block->run($item)) {
+                ++$i;
+            }
+        }
+
+        $self->new([map { $self->new($_) } @new]);
+    }
+
     sub slices {
         my ($self, $n) = @_;
 
@@ -904,8 +934,6 @@ package Sidef::Types::Array::Array {
         $self->new(\@array);
     }
 
-    *collect = \&map;
-
     sub map_kv {
         my ($self, $code) = @_;
 
@@ -917,8 +945,6 @@ package Sidef::Types::Array::Array {
         $self->new(\@arr);
     }
 
-    *collect_kv = \&map_kv;
-
     sub flat_map {
         my ($self, $code) = @_;
 
@@ -948,7 +974,6 @@ package Sidef::Types::Array::Array {
         $self->new(\@array);
     }
 
-    *filter = \&grep;
     *select = \&grep;
 
     sub grep_kv {
@@ -962,7 +987,6 @@ package Sidef::Types::Array::Array {
         $self->new(\@arr);
     }
 
-    *filter_kv = \&grep_kv;
     *select_kv = \&grep_kv;
 
     sub group_by {
@@ -1287,6 +1311,11 @@ package Sidef::Types::Array::Array {
         $self;
     }
 
+    sub compact {
+        my ($self) = @_;
+        $self->new([grep { defined($_) } @{$self}]);
+    }
+
     sub unique {
         my ($self) = @_;
 
@@ -1469,7 +1498,7 @@ package Sidef::Types::Array::Array {
         my $ref = ref($obj);
 
         foreach my $item (@{$self}) {
-            if (ref($item) eq $ref || eval { $item->SUPER::isa($ref) }) {
+            if (ref($item) eq $ref || UNIVERSAL::isa($item, $ref)) {
                 return (Sidef::Types::Bool::Bool::TRUE);
             }
         }
@@ -1789,7 +1818,7 @@ package Sidef::Types::Array::Array {
         my @array;
         my $sub;
         foreach my $item (@{$self}) {
-            if (ref($item) and defined(eval { $sub = $item->SUPER::can('copy') })) {
+            if (ref($item) and defined($sub = UNIVERSAL::can($item, 'copy'))) {
                 CORE::push(@array, $sub->($item));
             }
             else {
@@ -1896,7 +1925,6 @@ package Sidef::Types::Array::Array {
     *remove_last_if = \&delete_last_if;
 
     sub to_list { @{$_[0]} }
-    *as_list = \&to_list;
 
     sub dump {
         my ($self) = @_;
@@ -1906,7 +1934,7 @@ package Sidef::Types::Array::Array {
                 ', ',
                 map {
                     my $item = defined($self->[$_]) ? $self->[$_] : 'nil';
-                    ref($item) && defined(eval { $item->can('dump') }) ? $item->dump() : $item;
+                    ref($item) && defined(UNIVERSAL::can($item, 'dump')) ? $item->dump() : $item;
                   } 0 .. $#{$self}
               )
               . ']'
