@@ -330,6 +330,29 @@ package Sidef::Types::Hash::Hash {
                    [map { Sidef::Types::Array::Array->new($_->[1], $self->{$_->[0]}) } (sort { $a->[2] cmp $b->[2] } @array)]);
     }
 
+    sub sort {
+        my ($self, $code) = @_;
+
+        if (defined $code) {
+            return
+              Sidef::Types::Array::Array->new(
+                                              [
+                                               map { Sidef::Types::Array::Array->new($_->[1], $self->{$_->[0]}) } (
+                                                        sort { scalar $code->run($a->[1], $b->[1]) }
+                                                          map { [$_, Sidef::Types::String::String->new($_)] } CORE::keys %$self
+                                               )
+                                              ]
+                                             );
+        }
+
+        Sidef::Types::Array::Array->new(
+            map {
+                Sidef::Types::Array::Array->new(Sidef::Types::String::String->new($_), $self->{$_})
+              }
+              sort CORE::keys %$self
+        );
+    }
+
     sub to_a {
         my ($self) = @_;
         Sidef::Types::Array::Array->new(
@@ -379,8 +402,6 @@ package Sidef::Types::Hash::Hash {
         map { (Sidef::Types::String::String->new($_), $self->{$_}) } CORE::keys %$self;
     }
 
-    *as_list = \&to_list;
-
     sub dump {
         my ($self) = @_;
 
@@ -399,7 +420,7 @@ package Sidef::Types::Hash::Hash {
                            my $val = $self->{$_};
                            (@keys > 1 ? (' ' x $Sidef::SPACES) : '')
                              . "${Sidef::Types::String::String->new($_)->dump} => "
-                             . (eval { $val->can('dump') } ? ${$val->dump} : defined($val) ? $val : 'nil')
+                             . (defined(UNIVERSAL::can($val, 'dump')) ? ${$val->dump} : defined($val) ? $val : 'nil')
                          } @keys
                      )
                      . (@keys > 1 ? ("\n" . (' ' x ($Sidef::SPACES - $Sidef::SPACES_INCR))) : '')
